@@ -1,11 +1,7 @@
-from itertools import count
-import socket
 import uuid
 
-
 import eventlet
 from eventlet.event import Event
-from kombu import Connection
 from mock import patch, Mock, call
 import pytest
 
@@ -15,7 +11,7 @@ from nameko.dependencies import InjectionProvider, injection, DependencyFactory
 from nameko.events import event_handler
 from nameko.exceptions import (
     RemoteError, MethodNotFound, UnknownService, IncorrectSignature)
-from nameko.messaging import AMQP_URI_CONFIG_KEY, QueueConsumer
+from nameko.messaging import QueueConsumer
 from nameko.rpc import (
     rpc, rpc_proxy, RpcConsumer, RpcProvider, ReplyListener)
 from nameko.standalone.rpc import RpcProxy
@@ -90,37 +86,6 @@ class ExampleService(object):
         pass
 
 
-class FailingConnection(Connection):
-    exc_type = socket.error
-
-    def __init__(self, *args, **kwargs):
-        self.failure_count = 0
-        self.max_failure_count = kwargs.pop('max_failure_count', count(0))
-        return super(FailingConnection, self).__init__(*args, **kwargs)
-
-    @property
-    def should_raise(self):
-        return self.failure_count < self.max_failure_count
-
-    def maybe_raise(self, fun, *args, **kwargs):
-        if self.should_raise:
-            raise self.exc_type()
-        return fun(*args, **kwargs)
-
-    def ensure(self, obj, fun, **kwargs):
-        def wrapped(*args, **kwargs):
-            return self.maybe_raise(fun, *args, **kwargs)
-        kwargs['interval_start'] = 0
-        kwargs['interval_step'] = 0
-        return super(FailingConnection, self).ensure(obj, wrapped, **kwargs)
-
-    def connect(self, *args, **kwargs):
-        if self.should_raise:
-            self.failure_count += 1
-            raise self.exc_type()
-        return super(FailingConnection, self).connect(*args, **kwargs)
-
-
 @pytest.yield_fixture
 def get_rpc_exchange():
     with patch('nameko.rpc.get_rpc_exchange', autospec=True) as patched:
@@ -412,46 +377,36 @@ def test_rpc_incorrect_signature(container_factory, rabbit_config):
     container.start()
 
     method_calls = [
-        (('no_args', (), {}), None),
-        (('no_args', ('bad arg',), {}),
-            "no_args() takes no arguments (1 given)"),
-        (('args_only', ('arg',), {}), None),
-        (('args_only', (), {'a': 'arg'}), None),
-        (('args_only', (), {'arg': 'arg'}),
-            "args_only() got an unexpected keyword argument 'arg'"),
-        (('kwargs_only', ('a',), {}), None),
-        (('kwargs_only', (), {'a': 'arg'}), None),
-        (('kwargs_only', (), {'arg': 'arg'}),
-            "kwargs_only() got an unexpected keyword argument 'arg'"),
-        (('star_args', ('a', 'b'), {}), None),
-        (('star_args', (), {'c': 'c'}),
-            "star_args() got an unexpected keyword argument 'c'"),
-        (('args_star_args', ('a',), {}), None),
-        (('args_star_args', ('a', 'b'), {}), None),
-        (('args_star_args', (), {}),
-            "args_star_args() takes at least 1 argument (0 given)"),
-        (('args_star_args', (), {'c': 'c'}),
-            "args_star_args() got an unexpected keyword argument 'c'"),
-        (('args_star_kwargs', ('a',), {}), None),
-        (('args_star_kwargs', ('a', 'b'), {}),
-            "args_star_kwargs() takes exactly 1 argument (2 given)"),
-        (('args_star_kwargs', ('a', 'b'), {'c': 'c'}),
-            "args_star_kwargs() takes exactly 1 argument (3 given)"),
-        (('args_star_kwargs', (), {}),
-            "args_star_kwargs() takes exactly 1 argument (0 given)"),
+        (('no_args', (), {}), True),
+        (('no_args', ('bad arg',), {}), False),
+        (('args_only', ('arg',), {}), True),
+        (('args_only', (), {'a': 'arg'}), True),
+        (('args_only', (), {'arg': 'arg'}), False),
+        (('kwargs_only', ('a',), {}), True),
+        (('kwargs_only', (), {'a': 'arg'}), True),
+        (('kwargs_only', (), {'arg': 'arg'}), False),
+        (('star_args', ('a', 'b'), {}), True),
+        (('star_args', (), {'c': 'c'}), False),
+        (('args_star_args', ('a',), {}), True),
+        (('args_star_args', ('a', 'b'), {}), True),
+        (('args_star_args', (), {}), False),
+        (('args_star_args', (), {'c': 'c'}), False),
+        (('args_star_kwargs', ('a',), {}), True),
+        (('args_star_kwargs', ('a', 'b'), {}), False),
+        (('args_star_kwargs', ('a', 'b'), {'c': 'c'}), False),
+        (('args_star_kwargs', (), {}), False),
     ]
 
-    for signature, expected_error in method_calls:
+    for signature, is_valid_call in method_calls:
 
         method_name, args, kwargs = signature
 
         with RpcProxy("service", rabbit_config) as proxy:
             method = getattr(proxy, method_name)
 
-            if expected_error:
-                with pytest.raises(IncorrectSignature) as exc_info:
+            if not is_valid_call:
+                with pytest.raises(IncorrectSignature):
                     method(*args, **kwargs)
-                assert exc_info.value.message == expected_error
             else:
                 method(*args, **kwargs)  # no raise
 
@@ -530,48 +485,6 @@ def test_rpc_container_being_killed_retries(
     assert waiter.wait() == 'result_a'  # now completed
 
 
-def test_rpc_responder_auto_retries(container_factory, rabbit_config,
-                                    rabbit_manager):
-
-    container = container_factory(ExampleService, rabbit_config)
-    container.start()
-
-    uri = container.config[AMQP_URI_CONFIG_KEY]
-    conn = FailingConnection(uri, max_failure_count=2)
-
-    path = "kombu.connection.ConnectionPool.new"
-    with patch(path, autospec=True) as new_connection:
-        new_connection.return_value = conn
-
-        with RpcProxy("exampleservice", rabbit_config) as proxy:
-            assert proxy.task_a() == "result_a"
-        assert conn.failure_count == 2
-
-
-def test_rpc_responder_eventual_failure(container_factory, rabbit_config,
-                                        rabbit_manager):
-
-    container = container_factory(ExampleService, rabbit_config)
-    container.start()
-
-    uri = container.config[AMQP_URI_CONFIG_KEY]
-    conn = FailingConnection(uri)
-
-    path = "kombu.connection.ConnectionPool.new"
-    with patch(path, autospec=True) as new_connection:
-        new_connection.return_value = conn
-
-        with RpcProxy("exampleservice", rabbit_config) as proxy:
-            eventlet.spawn(proxy.task_a)
-
-        with eventlet.Timeout(10):
-            with pytest.raises(Exception) as exc_info:
-                container.wait()
-            assert type(exc_info.value) == socket.error
-
-# test reply-to and correlation-id correct
-
-
 def test_rpc_consumer_sharing(container_factory, rabbit_config,
                               rabbit_manager):
     """ Verify that the RpcConsumer unregisters from the queueconsumer when
